==> databene-benerator-0.7.7-sources.jar: org/databene/benerator/script/BeneratorScriptFactory.java <==
/*
 * (c) Copyright 2009-2011 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License.
 *
 * For redistributing this software or a derivative work under a license other
 * than the GPL-compatible Free Software License as defined by the Free
 * Software Foundation or approved by OSI, you must first obtain a commercial
 * license to this software product from Volker Bergmann.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.benerator.script;

import java.io.IOException;

import org.databene.commons.IOUtil;
import org.databene.commons.ParseException;
import org.databene.script.DatabeneScriptParser;
import org.databene.script.Script;
import org.databene.script.ScriptFactory;

/**
 * {@link ScriptFactory} implementation for BeneratorScript.<br/>
 * <br/>
 * Created at 09.10.2009 06:46:51
 * @since 0.6.0
 * @author Volker Bergmann
 */

public class BeneratorScriptFactory implements ScriptFactory {

    public Script parseText(String text) throws ParseException {
        return new BeneratorScript(DatabeneScriptParser.parseExpression(text), text);
    }

    public Script readFile(String uri) throws ParseException, IOException {
	    String text = IOUtil.getContentOfURI(uri);
	    return parseText(text);
    }

}

==> databene-benerator-0.9.8-sources.jar: org/databene/benerator/script/BeneratorScriptFactory.java <==
/*
 * (c) Copyright 2009-2013 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License.
 *
 * For redistributing this software or a derivative work under a license other
 * than the GPL-compatible Free Software License as defined by the Free
 * Software Foundation or approved by OSI, you must first obtain a commercial
 * license to this software product from Volker Bergmann.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.benerator.script;

import java.io.IOException;

import org.databene.commons.IOUtil;
import org.databene.commons.ParseException;
import org.databene.formats.script.Script;
import org.databene.formats.script.ScriptFactory;
import org.databene.script.DatabeneScriptParser;

/**
 * {@link ScriptFactory} implementation for BeneratorScript.<br/>
 * <br/>
 * Created at 09.10.2009 06:46:51
 * @since 0.6.0
 * @author Volker Bergmann
 */

public class BeneratorScriptFactory implements ScriptFactory {

    @Override
	public Script parseText(String text) throws ParseException {
        return new BeneratorScript(DatabeneScriptParser.parseExpression(text), text);
    }

    @Override
	public Script readFile(String uri) throws ParseException, IOException {
	    String text = IOUtil.getContentOfURI(uri);
	    return parseText(text);
    }

}
